@@ -46,6 +46,8 @@ extern const char *title_begin;
 extern const char *title_end;
 extern const char *header_begin;
 extern const char *header_end;
+extern const char *poweredby_begin;
+extern const char *poweredby_end;
 extern const char *cvslink_begin;
 extern const char *cvslink_end;
 extern const char *caution_begin;
@@ -130,8 +132,6 @@ const char *gen_href_end(void);
 const char *gen_list_begin(void);
 const char *gen_list_body(const char *, const char *, const char *);
 const char *gen_list_end(void);
-const char *gen_div_begin(const char *);
-const char *gen_div_end(void);
 const char *gen_form_begin(const char *);
 const char *gen_form_end(void);
 const char *gen_input(const char *, const char *, const char *);
