@@ -249,6 +249,7 @@ int definition_header=NO_HEADER;	/* (NO|BEFORE|RIGHT|AFTER)_HEADER */
 const char *htags_options = NULL;
 const char *include_file_suffixes = "h,hxx,hpp,H,inc.php";
 static const char *langmap = DEFAULTLANGMAP;
+int grtags_is_empty = 0;
 
 static struct option const long_options[] = {
 	/*
@@ -1002,7 +1003,7 @@ makecommonpart(const char *title, const char *defines, const char *files)
 	strbuf_puts(sb, title_begin);
 	strbuf_puts(sb, title);
 	strbuf_puts_nl(sb, title_end);
-	strbuf_puts_nl(sb, gen_div_begin("right"));
+	strbuf_puts_nl(sb, poweredby_begin);
 	strbuf_sprintf(sb, "Last updated %s%s\n", now(), br);
 	if (Iflag) {
 		snprintf(buf, sizeof(buf), "Powered by GLOBAL-%s.", get_version());
@@ -1017,7 +1018,7 @@ makecommonpart(const char *title, const char *defines, const char *files)
 			gen_href_end(),
 			br);
 	}
-	strbuf_puts_nl(sb, gen_div_end());
+	strbuf_puts_nl(sb, poweredby_end);
 	strbuf_puts_nl(sb, hr);
 	/*
 	 * Print items according to the value of variable 'item_order'.
@@ -1579,6 +1580,12 @@ main(int argc, char **argv)
 			else
 				die("--tabs option requires numeric value.");
                         break;
+		case OPT_NCOL:
+			if (atoi(optarg) > 0)
+				ncol = atoi(optarg);
+			else
+				die("--ncol option requires numeric value.");
+                        break;
 		case OPT_TREE_VIEW:
 			tree_view = 1;
 			if (optarg)
@@ -1840,7 +1847,7 @@ main(int argc, char **argv)
 		else if (!strcmp(distpath, strbuf_value(sb)))
 			; /* nothing to do */
 		else if (overwrite_key == 0)
-			die("The site key '%s' is not unique. please change it or use --overwrite-key option.", sitekey);
+			die("The site key '%s' is not unique, please change it or use --overwrite-key option.", sitekey);
 		else	/* New key value without --overwrite-key option */
 			try_writing = 1;
 		/*
@@ -1885,6 +1892,13 @@ main(int argc, char **argv)
 		 */
 		gtop = gtags_open(dbpath, cwdpath, GTAGS, GTAGS_READ, 0);
 		gtags_close(gtop);
+		/*
+		 * Check whether GRTAGS is empty.
+		 */
+		gtop = gtags_open(dbpath, cwdpath, GRTAGS, GTAGS_READ, 0);
+		if (gtags_first(gtop, NULL, 0) == NULL)
+			grtags_is_empty = 1;
+		gtags_close(gtop);
 	}
 	/*
 	 * make dbpath absolute.
@@ -1945,7 +1959,9 @@ main(int argc, char **argv)
 	 * (#) check if GTAGS, GRTAGS is the latest.
 	 */
 	if (get_dbpath())
-		message(" Using %s/GTAGS", get_dbpath());
+		message(" Using %s/GTAGS.", get_dbpath());
+	if (grtags_is_empty)
+		message(" GRTAGS is empty.");
 	if (gpath_open(get_dbpath(), 0) < 0)
 		die("GPATH not found.");
 	if (!w32) {
@@ -2021,12 +2037,13 @@ main(int argc, char **argv)
 		if (chmod(makepath(distpath, ".htaccess", NULL), 0644) < 0)
 			die("cannot chmod .htaccess skeleton.");
 		/*
-		 * Always make bless.sh.
 		 * Don't grant execute permission to bless script.
 		 */
-		makebless("bless.sh");
-		if (chmod(makepath(distpath, "bless.sh", NULL), 0640) < 0)
-			die("cannot chmod bless script.");
+		if (Sflag) {
+			makebless("bless.sh");
+			if (chmod(makepath(distpath, "bless.sh", NULL), 0640) < 0)
+				die("cannot chmod bless script.");
+		}
 	} else {
 		message("[%s] (1) making CGI program ...(skipped)", now());
 	}
