@@ -418,6 +418,25 @@ put_anchor(char *name, int type, int lineno)
 		}
 	}
 }
+/*
+ * put_anchor_force: output HTML anchor without warning.
+ *
+ *	i)	name	tag
+ *	i)	type	tag type
+ *	i)	lineno	current line no
+ */
+void
+put_anchor_force(char *name, int length, int lineno)
+{
+	STATIC_STRBUF(sb);
+	int saveflag = wflag;
+
+	strbuf_clear(sb);
+	strbuf_nputs(sb, name, length);
+	wflag = 0;
+	put_anchor(strbuf_value(sb), 'R', lineno);
+	wflag = saveflag;
+}
 /*
  * put_include_anchor: output HTML anchor.
  *
@@ -702,10 +721,7 @@ src2html(const char *src, const char *html, int notsource)
 	out = get_descripter(fileop_out);
 	strbuf_clear(outbuf);
 
-	if (Fflag)
-		snprintf(indexlink, sizeof(indexlink), "../files.%s", normal_suffix);
-	else
-		snprintf(indexlink, sizeof(indexlink), "../mains.%s", normal_suffix);
+	snprintf(indexlink, sizeof(indexlink), "../mains.%s", normal_suffix);
 	fputs_nl(gen_page_begin(src, SUBDIR), out);
 	fputs_nl(body_begin, out);
 	/*
